@@ -11,10 +11,13 @@
 #include "QXmppPromise.h"
 #include "QXmppUtils.h"
 
-#include <QStringBuilder>
+#include "StringLiterals.h"
+
 #include <QUuid>
 
 using namespace QXmpp;
+using namespace QXmpp::Private;
+
 using Jmi = QXmppJingleMessageInitiation;
 using JmiManager = QXmppJingleMessageInitiationManager;
 using JmiElement = QXmppJingleMessageInitiationElement;
@@ -102,7 +105,7 @@ QXmppTask<SendResult> QXmppJingleMessageInitiation::reject(std::optional<QXmppJi
     if (!reason) {
         reason = QXmppJingleReason();
         reason->setType(QXmppJingleReason::Busy);
-        reason->setText(QStringLiteral("Busy"));
+        reason->setText(u"Busy"_s);
     }
 
     jmiElement.setReason(reason);
@@ -126,7 +129,7 @@ QXmppTask<SendResult> QXmppJingleMessageInitiation::retract(std::optional<QXmppJ
     if (!reason) {
         reason = QXmppJingleReason();
         reason->setType(QXmppJingleReason::Cancel);
-        reason->setText(QStringLiteral("Retracted"));
+        reason->setText(u"Retracted"_s);
     }
 
     jmiElement.setReason(reason);
@@ -150,7 +153,7 @@ QXmppTask<SendResult> QXmppJingleMessageInitiation::finish(std::optional<QXmppJi
     if (!reason) {
         reason = QXmppJingleReason();
         reason->setType(QXmppJingleReason::Success);
-        reason->setText(QStringLiteral("Success"));
+        reason->setText(u"Success"_s);
     }
 
     jmiElement.setReason(reason);
@@ -270,7 +273,7 @@ QXmppJingleMessageInitiationManager::~QXmppJingleMessageInitiationManager() = de
 /// \cond
 QStringList QXmppJingleMessageInitiationManager::discoveryFeatures() const
 {
-    return { ns_jingle_message_initiation };
+    return { ns_jingle_message.toString() };
 }
 /// \endcond
 
@@ -288,7 +291,7 @@ QXmppTask<QXmppJingleMessageInitiationManager::ProposeResult> QXmppJingleMessage
 
     sendMessage(jmiElement, callPartnerJid).then(this, [this, promise, callPartnerJid](SendResult result) mutable {
         if (auto error = std::get_if<QXmppError>(&result)) {
-            warning(u"Error sending Jingle Message Initiation proposal: " % error->description);
+            warning(u"Error sending Jingle Message Initiation proposal: " + error->description);
             promise.finish(*error);
         } else {
             promise.finish(addJmi(callPartnerJid));
@@ -313,11 +316,6 @@ bool QXmppJingleMessageInitiationManager::handleMessage(const QXmppMessage &mess
 
     return false;
 }
-
-void QXmppJingleMessageInitiationManager::setClient(QXmppClient *client)
-{
-    QXmppClientExtension::setClient(client);
-}
 /// \endcond
 
 ///
@@ -480,7 +478,7 @@ bool QXmppJingleMessageInitiationManager::handleExistingSession(const std::share
     // Old session will be finished with reason "Expired".
     QXmppJingleReason reason;
     reason.setType(QXmppJingleReason::Expired);
-    reason.setText(QStringLiteral("Session migrated"));
+    reason.setText(u"Session migrated"_s);
 
     // Tell the old session to be finished.
     Q_EMIT existingJmi->closed(Jmi::Finished { reason, jmiElementId });
@@ -517,7 +515,7 @@ bool QXmppJingleMessageInitiationManager::handleNonExistingSession(const std::sh
 {
     QXmppJingleReason reason;
     reason.setType(QXmppJingleReason::Expired);
-    reason.setText(QStringLiteral("Tie-Break"));
+    reason.setText(u"Tie-Break"_s);
 
     if (QUuid::fromString(existingJmi->id()) < QUuid::fromString(jmiElementId)) {
         // Jingle message initiator with lower ID rejects the other proposal.
